Processor.App.Pipeline.pipeline.ProcessorPipeline.\_\_init\_\_
==============================================================

.. currentmodule:: Processor.App.Pipeline.pipeline

.. automethod:: ProcessorPipeline.__init__